#
# spec file for package python-pyasn1
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pyasn1
Version:        0.2.2
Release:        1.1
Summary:        ASN.1 types and codecs
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://github.com/etingof/pyasn1
Source:         https://pypi.io/packages/source/p/pyasn1/pyasn1-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-pytest
BuildRequires:  python-setuptools
Provides:       python-asn1 = %{version}
Obsoletes:      python-asn1 < 0.1.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This is an implementation of ASN.1 types and codecs in Python programming
language. It has been first written to support particular protocol (SNMP) but
then generalized to be suitable for a wide range of protocols based on ASN.1
specification.

%prep
%setup -q -n pyasn1-%{version}

%build
python setup.py build

%check
python setup.py test

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES.rst LICENSE.rst README.md THANKS.txt TODO.rst doc
%{python_sitelib}/*

%changelog
* Tue Feb  7 2017 michael@stroeder.com
- updated to upstream release 0.2.2 with security fixes
- updated project and source URLs and list of doc files
  Revision 0.2.2, released 07-02-2017
- FIX TO A SECURITY WEAKNESS: define length only decoders could have successfully
  processed indefinite length serialization.
- FIX TO A SECURITY WEAKNESS: canonical decoders (CER/DER) may have successfully
  consumed non-canonical variations of (otherwise valid) serialization.
- Broken Enumerated subtyping fixed.
  Revision 0.2.1, released 05-02-2017
- FIX TO A SECURITY WEAKNESS: BER decoder improperly cached long tags.
- New "native" codec implemented to transform pyasn1 types to Python built-in types and back.
- Switched to new-style classes.
- Sphinx documentation added.
- BitString improvements:
  * simple string of binary digits is now supported as initializer
  * default str() yields string of binary digits (used to yield str(tuple())
  * binValue and hexValue initializers added
  * .asNumbers(), .asOctets() and asInteger() representation added
- Components of constructed ASN.1 types can now be populated with
  uninitialized ASN.1 objects by assigning either noValue sentinel or
  setupComponent() function return in addition to now-legacy None sentinel.
  This should improve code readability.
- NoValue class improved to become a singleton and catch more kinds
  of access to it.
- Compatibility wrappers str2octs() and oct2strs() fixed to run over
  iso-8859-1 encoding.
- Integer changed to emit Real instance if division produces a float.
- True division operation now supported by Integer type.
- The __contains__(), __reverse__() methods implemented for container types
- Iterator protocol support implemented for all container types.
  Warning, warning, warning: this change may potentially affect backward
  compatibility when:
  * user class overrides __getitem__() without overriding __iter__()
  * when user code iterates over SEQUENCE object to get its components (now keys will be yielded)
- Almost complete Python list and dict protocols added to SequenceOf/SetOf and
  Sequence/Set respectively
- Fix to divmod operation implementation in Integer type.
- Fix to IntegerDecoder's precomputed value map on Python 3.
- Fix to base ASN.1 types to run in "unicode_literals" mode.
- Fix to composite constraints "+" operands ordering (AbstractConstraintSet.__radd__)
- Fix to constraints merge in .subtype() -- on merge existing constraints are
  expanded to accommodate new constraints, not the other way round. When existing
  constraints are wrapped in ConstraintsIntersection composite, additional
  constraints being added on subtyping effectively further narrow the set of
  allowed values, which aligns well with the notion of subtyping.
- Fix to NamedTypes methods to handle .getTagMap() returning None
- Fix to Set/Sequence.setDefaultComponents() to return self
- Copyright notice added to non-trivial source code files.
- Author's email changed, copyright extended to 2017
* Tue Oct  6 2015 hpj@urpla.net
- updated to upstream release 0.1.9
  - Wheel distribution format now supported.
  - Extensions added to text files, CVS attic flushed.
  - Fix to make uninitilaized pyasn1 objects failing properly on hash().
  - Fix to ObjectIdentifier initialization from unicode string.
  - Fix to CER/DER Boolean decoder - fail on non single-octet payload.
* Sat Jul  4 2015 michael@stroeder.com
- updated to upstrean release 0.1.8 (fate#318838)
  - ObjectIdentifier codec fixed to work properly with arc 0 and arc 2 values.
  - Explicit limit on ObjectIdentifier arc value size removed.
  - Unicode initializer support added to OctetString type and derivatives.
  - New prettyPrintType() abstract method implemented to base pyasn1 types
    to facilitate encoding errors analisys.
  - The __str__() method implemented to Tag, TagSet and TagMap classes to
    ease encoding errors troubleshooting.
    easing encoding errors
  - Fix to SEQUENCE and SET types to give them their private componentTypes
    collection (which is a NamedTypes object) so that they won't collide in
    a MT execution environment.
  - Missing T61String,ISO646String character types and ObjectDescriptor useful
    type added.
  - Distribute is gone, switched to setuptools completely.
  - Missing NamedValues.__repr__() added.
  - The base.NoValue() class, that indicates uninitialized ASN.1 object,
    made public.
  - The base.NoValue() class instances now support __repr__() what makes
    possible to perform repr() on uninitialized pyasn1 types objects.
  - When comparing ASN.1 types, by-tag and/or by-constraints matching
    can now be performed with the isSuperTypeOf()/isSameTypeWith() optional
    flags.
  - Constructed types now verify their consistency by invoking
    isSameTypeWith(matchTags=True, matchConstraints=False) and
    isSuperTypeOf(matchTags=False, matchConstraints=True) for each of their
    components rather than isSuperTypeOf() as it used to be. Constriants check
    could be enforced to isSameTypeWith() with the strictConstraints=True
    constructed classes attribute.
  - Constructed types can now be initialized with new .setComponents() method
    which accepts both var-args and keyword-args. Default repr() modified to
    reflect this change.
  - NamedTypes() and NamedValues() made comparable.
  - Test coverage extended to cover pyasn1 types __repr__() function.
  - The abs(Integer()) & abs(Real()) operation now returns respective pyasn1
    type, not a Python type.
  - More Python magic methods implementations added to Integer & Real classes
    (e.g.  __pos__, __neg__, __round__, __floor__, __ceil__, __trunc__)
  - The Integer.__invert__ Python magic method implemented.
  - The OctetString.__int__() and .__float__() magic methods implemented.
  - Handle the case of null writer at Debug printer.
  - BitString encoder/decoder performance improved.
  - Built-in debugging is now based on Python logging module.
  - Fix to NamedType.__repr__() to work properly.
  - Fixes to __repr__() implementation of many built-in ASN.1 types to take into
    account all of their initializers such as tagSet, subtypeSpec etc.
  - String typed float initializer to REAL type now supported.
  - Float typed mantissa initializer to REAL type for base 2 added.
  - Encoding bases 8 and 16 support for REAL type binary encoder added.
  - More strict CER/DER encoders added for GeneralizedTime and UTCTime types.
  - Asn1Item.hasValue() added to easily distinguish initalized ASN.1 objects
    from uninitialized ones (e.g. pure types).
  - Fix to REAL type binary decoder to handle different bases and scale factor.
  - Fix to TagSet.repr() to include [obsolete] baseTag information.
  - Fix to broken REAL type decoding handling.
  - Fix to BitString and OctetString decoders dealing with constructed
    encoding -- it used to be possible to embed other types in substrate.
  - Fix to end-of-octest sentinel handling:
  * require strict two-zeros sentinel encoding
  * recognize EOO sentinel only when explicitly requested by caller
    of the decoder via allowEoo=True parameter (warning: API change)
  - DER codec hardened not to tolerate indefinite length encoding/decoding.
* Wed Apr 22 2015 mcihar@suse.cz
- Run testsuite in %%check
* Tue Mar  3 2015 lchiquitto@suse.com
- Reflect license change (from BSD-3-Clause to BSD-2-Clause) which
  happened in version 0.1.7 in the spec file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
- Fix changes file
* Tue May  7 2013 michael@stroeder.com
- updated to upstrean release 0.1.7
  - License updated to vanilla BSD 2-Clause to ease package use
    (http://opensource.org/licenses/BSD-2-Clause).
  - Test suite made discoverable by unittest/unittest2 discovery feature.
  - Fix to decoder working on indefinite length substrate -- end-of-octets
    marker is now detected by both tag and value. Otherwise zero values may
    interfere with end-of-octets marker.
  - Fix to decoder to fail in cases where tagFormat indicates inappropriate
    format for the type (e.g. BOOLEAN is always PRIMITIVE, SET is always
    CONSTRUCTED and OCTET STRING is either of the two)
  - Fix to REAL type encoder to force primitive encoding form encoding.
  - Fix to CHOICE decoder to handle explicitly tagged, indefinite length
    mode encoding
  - Fix to REAL type decoder to handle negative REAL values correctly. Test
    case added.
* Fri Jan 18 2013 michael@stroeder.com
- updated to upstrean release 0.1.6
  - The compact (valueless) way of encoding zero INTEGERs introduced in
    0.1.5 seems to fail miserably as the world is filled with broken
    BER decoders. So we had to back off the *encoder* for a while.
    There's still the IntegerEncoder.supportCompactZero flag which
    enables compact encoding form whenever it evaluates to True.
  - Report package version on debugging code initialization.
- Changes from version 0.1.5:
  - Documentation updated and split into chapters to better match
    web-site contents.
  - Make prettyPrint() working for non-initialized pyasn1 data objects. It
    used to throw an exception.
  - Fix to encoder to produce empty-payload INTEGER values for zeros
  - Fix to decoder to support empty-payload INTEGER and REAL values
  - Fix to unit test suites imports to be able to run each from
    their current directory
* Fri Jul 27 2012 michael@stroeder.com
- updated to upstrean release 0.1.4
  * A built-in de/serialization debugging facility added
  * Package versioning added (pyasn1.__version__)
  * Leading sub-OIDs overflow condition handled
  * REAL type exponent encoding implemented properly at BER codec
  * Boolean BER decoder fixed to allow arbitrary payload
  * Leading 0x80 octet now handled properly by DER/CER/DER
    ObjectIdentifier decoder
- includes fix needed by python-ldap's module ldap.syncrepl
* Wed Apr 25 2012 michael@stroeder.com
- updated to upstrean release 0.1.3
  - Include class name into asn1 value constraint violation exception.
  - Fix to OctetString.prettyOut() method that looses leading zero when
    building hex string.
* Wed Apr 18 2012 saschpe@suse.de
- Fix obsoletes for python-asn1 instead
* Tue Apr 17 2012 dmueller@suse.com
- remove self-obsoletes
* Fri Mar 23 2012 michael@stroeder.com
- updated to upstrean release 0.1.2
  - Fix to __long__() to actually return longs on py2k
  - Fix to OctetString.__str__() workings of a non-initialized object.
  - Fix to quote initializer of OctetString.__repr__()
  - Minor fix towards ObjectIdentifier.prettyIn() reliability
  - ObjectIdentifier.__str__() is aliased to prettyPrint()
  - Exlicit repr() calls replaced with '%%r'
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Nov  8 2011 highwaystar.ru@gmail.com
- updated to 0.1.1
  * Hex/bin string initializer to OctetString object reworked
  (in a backward-incompatible manner)
  * Fixed float() infinity compatibility issue (affects 2.5 and earlier)
  * Fixed a bug/typo at Boolean CER encoder
  * Major overhawl for Python 2.4 -- 3.2 compatibility
  +  get rid of old-style types
  + drop string module usage
  + switch to rich comparation
  + drop explicit long integer type use
  + map()/filter() replaced with list comprehension
  + apply() replaced with */**args
  + switched to use 'key' sort() callback function
  + support both __nonzero__() and __bool__() methods
  + modified not to use py3k-incompatible exception syntax
  + getslice() operator fully replaced with getitem()
  + dictionary operations made 2K/3K compatible
  + base type for encoding substrate and OctetString-based types
    is now 'bytes' when running py3k and 'str' otherwise
  + OctetString and derivatives now unicode compliant.
  + OctetString now supports two python-neutral getters: asOcts() & asInts()
  + print OctetString content in hex whenever it is not printable otherwise
  + in test suite, implicit relative import replaced with the absolute one
  + in test suite, string constants replaced with numerics
* Wed Aug 31 2011 saschpe@gmx.de
- Packaged documentation
* Wed Aug 31 2011 saschpe@suse.de
- Initial version, obsoletes 'python-asn1'
